@@ -17,5 +17,4 @@
 # along with Carbon. If not, see <https://www.gnu.org/licenses/>.
 
 
-from ._main import Carbon
-from ._constants import __version__
+from .main import Carbon
